Pymux
=====

Pure-Python TMUX clone.


About
-----

Still experimental, but the idea is to create a fully functional tmux clone in
pure Python.


Running
-------

Right now, do: ```python client.py run```
